package Bundle::RT;

$VERSION = '0.030601';

1;

__END__

=head1 NAME

Bundle::RT - CPAN Bundle for RT Dependencies

=head1 SYNOPSIS

C< perl -MCPAN -e'install Bundle::RT' >

will tell the CPAN.pm module to install most of RT's dependent modules.

=head1 CONTENTS

Digest::MD5 2.27

DBI 1.37

Test::Inline

Class::ReturnValue 0.40

DBIx::SearchBuilder 1.39

Text::Template

File::Spec 0.8

HTML::Entities

HTML::Scrubber 0.08

Net::Domain

Log::Dispatch 2.0

Locale::Maketext 1.06

Locale::Maketext::Lexicon 0.32

Locale::Maketext::Fuzzy

MIME::Entity 5.108

Mail::Mailer 1.57

Net::SMTP

Text::Wrapper

Time::ParseDate

Time::HiRes

File::Temp

Term::ReadKey

Text::Autoformat

Text::Quoted 1.3

Tree::Simple 1.04

Scalar::Util

Module::Versions::Report

Cache::Simple::TimedExpiry

UNIVERSAL::require

Calendar::Simple

Params::Validate 0.02

Cache::Cache

Exception::Class 1.14

HTML::Mason 1.23

MLDBM

Errno

FreezeThaw

CGI::Cookie 1.20

Storable 2.08

Apache::Session 1.53

XML::RSS 1.05

HTTP::Server::Simple 0.07

HTTP::Server::Simple::Mason 0.09

GD

GD::Graph

GD::Text

Text::WikiFormat 0.76

HTML::TreeBuilder

HTML::FormatText

Getopt::Long 2.24

LWP::UserAgent


Regexp::Common

Test::Inline

Apache::Test

HTML::Form

HTML::TokeParser

WWW::Mechanize

Test::WWW::Mechanize

CGI 2.92

Module::Refresh

XML::Simple

=cut
